@@ -1,6 +1,8 @@
 .pfmix.xy <- function(x, y, w, xTheta, yTheta, ...)
 {
-  f <- array(data = 0.0, dim = length(x), dimnames = NULL)
+  n <- length(x)
+  
+  f <- array(data = 0.0, dim = n, dimnames = NULL)
 
   for (i in 1:length(w)) {
     if (xTheta[[i]]$pdf == .rebmix$pdf[1]) {
@@ -29,7 +31,19 @@
     else
     if (xTheta[[i]]$pdf == .rebmix$pdf[7]) {
       fix <- pgamma(as.numeric(x), scale = as.numeric(xTheta[[i]]$theta1), shape = as.numeric(xTheta[[i]]$theta2), ...)
-    }    
+    }
+    else
+    if (xTheta[[i]]$pdf == .rebmix$pdf[9]) {
+      output <- .C(C_RvonMisesCdf,
+        n = as.integer(n),
+        y = as.double(x),
+        Mean = as.double(xTheta[[i]]$theta1),
+        Kappa = as.double(xTheta[[i]]$theta2),
+        F = double(n),
+        PACKAGE = "rebmix")
+          
+      fix <- output$F        
+    }     
 
     if (yTheta[[i]]$pdf == .rebmix$pdf[1]) {
       fiy <- pnorm(as.numeric(y), mean = as.numeric(yTheta[[i]]$theta1), sd = as.numeric(yTheta[[i]]$theta2), ...)
@@ -57,8 +71,19 @@
     else
     if (yTheta[[i]]$pdf == .rebmix$pdf[7]) {
       fiy <- pgamma(as.numeric(y), scale = as.numeric(yTheta[[i]]$theta1), shape = as.numeric(yTheta[[i]]$theta2), ...)
-    }    
-    
+    }
+    else
+    if (yTheta[[i]]$pdf == .rebmix$pdf[9]) {
+      output <- .C(C_RvonMisesCdf,
+        n = as.integer(n),
+        y = as.double(y),
+        Mean = as.double(yTheta[[i]]$theta1),
+        Kappa = as.double(yTheta[[i]]$theta2),
+        F = double(n),
+        PACKAGE = "rebmix")
+          
+      fiy <- output$F
+    }         
 
     f <- f + w[i] * fix * fiy
   }
