@@ -136,20 +136,34 @@ function(object, ...)
     stop(sQuote("object"), " object of class RCLRMIX is requested!", call. = FALSE)
   }
   
-  c <- length(object@x@w[[object@pos]])  
+  c <- object@c - 1
   
-  combine <- rbind(as.number(1:c), as.number(object@from), as.number(object@to), as.number(object@EN), as.number(object@ED))
+  if (c > 0) {  
+    combine <- rbind(as.number(1:c), as.number(object@from), as.number(object@to), as.number(object@EN), as.number(object@ED))
   
-  combine <- gsub(" ", "", combine, fixed = TRUE)
+    combine <- gsub(" ", "", combine, fixed = TRUE)
   
-  rownames(combine) <- c("Number of clusters", "From cluster", "To cluster", "Entropy", "Entropy decrease")
-  colnames(combine) <- rep("", c)
+    rownames(combine) <- c("Number of clusters", "From cluster", "To cluster", "Entropy", "Entropy decrease")
+    colnames(combine) <- rep("", c)
   
-  combine <- capture.output(combine)[-1]
-  combine <- paste(combine, "\n", sep = "") 
-  combine <- gsub("\"", " ", combine, fixed = TRUE)
+    combine <- capture.output(combine)[-1]
+    combine <- paste(combine, "\n", sep = "") 
+    combine <- gsub("\"", " ", combine, fixed = TRUE)
   
-  cat(combine, sep = "")
+    cat(combine, sep = "")
+  }
+  else {
+    combine <- rbind(1)
+  
+    rownames(combine) <- "Number of clusters"
+    colnames(combine) <- ""
+  
+    combine <- capture.output(combine)[-1]
+    combine <- paste(combine, "\n", sep = "") 
+    combine <- gsub("\"", " ", combine, fixed = TRUE)
+  
+    cat(combine, sep = "") 
+  }
    
   rm(list = ls()) 
 }) ## summary
@@ -162,20 +176,34 @@ function(object, ...)
     stop(sQuote("object"), " object of class RCLRMVNORM is requested!", call. = FALSE)
   }
   
-  c <- length(object@x@w[[object@pos]])  
+  c <- object@c - 1
   
-  combine <- rbind(as.number(1:c), as.number(object@from), as.number(object@to), as.number(object@EN), as.number(object@ED))
+  if (c > 0) {
+    combine <- rbind(as.number(1:c), as.number(object@from), as.number(object@to), as.number(object@EN), as.number(object@ED))
   
-  combine <- gsub(" ", "", combine, fixed = TRUE)
+    combine <- gsub(" ", "", combine, fixed = TRUE)
   
-  rownames(combine) <- c("Number of clusters", "From cluster", "To cluster", "Entropy", "Entropy decrease")
-  colnames(combine) <- rep("", c)
+    rownames(combine) <- c("Number of clusters", "From cluster", "To cluster", "Entropy", "Entropy decrease")
+    colnames(combine) <- rep("", c)
   
-  combine <- capture.output(combine)[-1]
-  combine <- paste(combine, "\n", sep = "") 
-  combine <- gsub("\"", " ", combine, fixed = TRUE)
+    combine <- capture.output(combine)[-1]
+    combine <- paste(combine, "\n", sep = "") 
+    combine <- gsub("\"", " ", combine, fixed = TRUE)
   
-  cat(combine, sep = "")
+    cat(combine, sep = "")
+  }
+  else {
+    combine <- rbind(1)
+  
+    rownames(combine) <- "Number of clusters"
+    colnames(combine) <- ""
+  
+    combine <- capture.output(combine)[-1]
+    combine <- paste(combine, "\n", sep = "") 
+    combine <- gsub("\"", " ", combine, fixed = TRUE)
+  
+    cat(combine, sep = "") 
+  }  
   
   rm(list = ls()) 
 }) ## summary
